==> ml_management-0.6.0.tar.gz: ml_management-0.6.0/ML_management/sdk/__init__.py <==
from ML_management.sdk import dataset_loader, executor, experiment, job, model, parameters

list_model = model.list_model
list_dataset_loader = dataset_loader.list_dataset_loader
list_executor = executor.list_executor
add_ml_job = job.add_ml_job
job_by_name = job.job_by_name
job_metric_by_name = job.job_metric_by_name
list_model_version = model.list_model_version
list_dataset_loader_version = dataset_loader.list_dataset_loader_version
list_executor_version = executor.list_executor_version
get_model_version = model.get_model_version
rebuild_model_version_image = model.rebuild_model_version_image
print_model_schema_for_executor = executor.print_model_schema_for_executor
print_dataset_loader_schema = dataset_loader.print_dataset_loader_schema
print_executor_schema = executor.print_executor_schema
print_executor_roles = executor.print_executor_roles
get_logs = job.get_logs
get_build_logs = job.get_build_logs
get_venv_build_logs = job.get_venv_build_logs
serve_model = model.serve_model
stop_model_serving = model.stop_model_serving
check_inference_model_readiness = model.check_inference_model_readiness
get_required_classes_by_executor = executor.get_required_classes_by_executor
available_metrics = job.available_metrics
metric_history = job.metric_history
list_params_job = job.list_params_job
delete_model_version = model.delete_model_version
delete_model = model.delete_model
delete_executor_version = executor.delete_executor_version
delete_executor = executor.delete_executor
delete_dataset_loader = dataset_loader.delete_dataset_loader
delete_dataset_loader_version = dataset_loader.delete_dataset_loader_version
cancel_job = job.cancel_job
cancel_build_job_for_model_version = model.cancel_build_job_for_model_version
cancel_build_job_for_executor_version = executor.cancel_build_job_for_executor_version
cancel_venv_build_job_for_model_version = model.cancel_venv_build_job_for_model_version
set_experiment_tags = experiment.set_experiment_tags
reset_experiment_tags = experiment.reset_experiment_tags
set_experiment_description = experiment.set_experiment_description
delete_experiment_tag = experiment.delete_experiment_tag
get_experiment_by_id = experiment.get_experiment_by_id
get_experiment_by_name = experiment.get_experiment_by_name
create_experiment = experiment.create_experiment
ModelMethodParams = parameters.ModelMethodParams
ModelVersionChoice = parameters.ModelVersionChoice
ModelForm = parameters.ModelForm
ModelWithRole = parameters.ModelWithRole
AnyModelForm = parameters.AnyModelForm
DatasetLoaderMethodParams = parameters.DatasetLoaderMethodParams
DatasetLoaderForm = parameters.DatasetLoaderForm
DatasetLoaderWithRole = parameters.DatasetLoaderWithRole
AnyDatasetLoaderForm = parameters.AnyDatasetLoaderForm
get_dataset_loader_version_requirements = dataset_loader.get_dataset_loader_version_requirements
get_executor_version_requirements = executor.get_executor_version_requirements
get_model_version_requirements = model.get_model_version_requirements
get_dataset_loader_version_conda_env = dataset_loader.get_dataset_loader_version_conda_env
get_executor_version_conda_env = executor.get_executor_version_conda_env
get_executor_version = executor.get_executor_version
get_model_version_conda_env = model.get_model_version_conda_env
get_dataset_loader_version = dataset_loader.get_dataset_loader_version
delete_dataset_loader_version_tag = dataset_loader.delete_dataset_loader_version_tag
delete_executor_version_tag = executor.delete_executor_version_tag
delete_model_version_tag = model.delete_model_version_tag
set_dataset_loader_version_tags = dataset_loader.set_dataset_loader_version_tags
reset_dataset_loader_version_tags = dataset_loader.reset_dataset_loader_version_tags
set_executor_version_tags = executor.set_executor_version_tags
reset_executor_version_tags = executor.reset_executor_version_tags
set_model_version_tags = model.set_model_version_tags
reset_model_version_tags = model.reset_model_version_tags
set_dataset_loader_version_description = dataset_loader.set_dataset_loader_version_description
set_executor_version_description = executor.set_executor_version_description
set_model_version_description = model.set_model_version_description
set_model_description = model.set_model_description
set_executor_description = executor.set_executor_description
set_dataset_loader_description = dataset_loader.set_dataset_loader_description
delete_model_tag = model.delete_model_tag
delete_executor_tag = executor.delete_executor_tag
delete_dataset_loader_tag = dataset_loader.delete_dataset_loader_tag
set_dataset_loader_tags = dataset_loader.set_dataset_loader_tags
reset_dataset_loader_tags = dataset_loader.reset_dataset_loader_tags
set_executor_tags = executor.set_executor_tags
reset_executor_tags = executor.reset_executor_tags
set_model_tags = model.set_model_tags
reset_model_tags = model.reset_model_tags
get_latest_model_version = model.get_latest_model_version
get_latest_executor_version = executor.get_latest_executor_version
get_latest_dataset_loader_version = dataset_loader.get_latest_dataset_loader_version
get_initial_model_version = model.get_initial_model_version
get_initial_executor_version = executor.get_initial_executor_version
get_initial_dataset_loader_version = dataset_loader.get_initial_dataset_loader_version

set_dataset_loader_version_visibility = dataset_loader.set_dataset_loader_version_visibility
set_executor_version_visibility = executor.set_executor_version_visibility
set_model_version_visibility = model.set_model_version_visibility
set_model_visibility = model.set_model_visibility
set_executor_visibility = executor.set_executor_visibility
set_dataset_loader_visibility = dataset_loader.set_dataset_loader_visibility
set_experiment_visibility = experiment.set_experiment_visibility
set_job_visibility = job.set_job_visibility

pagination_model = model.pagination_model
pagination_model_version = model.pagination_model_version
pagination_executor = executor.pagination_executor
pagination_executor_version = executor.pagination_executor_version
pagination_dataset_loader = dataset_loader.pagination_dataset_loader
pagination_dataset_loader_version = dataset_loader.pagination_dataset_loader_version

==> ml_management-0.6.3rc10.tar.gz: ml_management-0.6.3rc10/ML_management/sdk/__init__.py <==
from ML_management.sdk import dataset_loader, executor, experiment, job, model, parameters

list_model = model.list_model
list_dataset_loader = dataset_loader.list_dataset_loader
list_executor = executor.list_executor
add_ml_job = job.add_ml_job
job_by_name = job.job_by_name
job_metric_by_name = job.job_metric_by_name
list_model_version = model.list_model_version
list_dataset_loader_version = dataset_loader.list_dataset_loader_version
list_executor_version = executor.list_executor_version
get_model_version = model.get_model_version
rebuild_model_version_image = model.rebuild_model_version_image
print_model_schema_for_executor = executor.print_model_schema_for_executor
generate_model_params_for_executor = executor.generate_model_params_for_executor
print_dataset_loader_schema = dataset_loader.print_dataset_loader_schema
print_executor_schema = executor.print_executor_schema
print_executor_roles = executor.print_executor_roles
get_logs = job.get_logs
get_build_logs = job.get_build_logs
get_venv_build_logs = job.get_venv_build_logs
serve_model = model.serve_model
stop_model_serving = model.stop_model_serving
check_inference_model_readiness = model.check_inference_model_readiness
get_required_classes_by_executor = executor.get_required_classes_by_executor
available_metrics = job.available_metrics
metric_history = job.metric_history
list_params_job = job.list_params_job
delete_model_version = model.delete_model_version
delete_model = model.delete_model
delete_executor_version = executor.delete_executor_version
delete_executor = executor.delete_executor
delete_dataset_loader = dataset_loader.delete_dataset_loader
delete_dataset_loader_version = dataset_loader.delete_dataset_loader_version
cancel_job = job.cancel_job
cancel_build_job_for_model_version = model.cancel_build_job_for_model_version
cancel_build_job_for_executor_version = executor.cancel_build_job_for_executor_version
cancel_venv_build_job_for_model_version = model.cancel_venv_build_job_for_model_version
set_experiment_tag = experiment.set_experiment_tag
set_experiment_description = experiment.set_experiment_description
delete_experiment_tag = experiment.delete_experiment_tag
get_experiment_by_id = experiment.get_experiment_by_name
get_experiment_by_name = experiment.get_experiment_by_name
ModelMethodParams = parameters.ModelMethodParams
ModelVersionChoice = parameters.ModelVersionChoice
ModelForm = parameters.ModelForm
ModelWithRole = parameters.ModelWithRole
AnyModelForm = parameters.AnyModelForm
DatasetLoaderMethodParams = parameters.DatasetLoaderMethodParams
DatasetLoaderForm = parameters.DatasetLoaderForm
DatasetLoaderWithRole = parameters.DatasetLoaderWithRole
AnyDatasetLoaderForm = parameters.AnyDatasetLoaderForm
get_dataset_loader_version_requirements = dataset_loader.get_dataset_loader_version_requirements
get_executor_version_requirements = executor.get_executor_version_requirements
get_model_version_requirements = model.get_model_version_requirements
get_dataset_loader_version_conda_env = dataset_loader.get_dataset_loader_version_conda_env
get_executor_version_conda_env = executor.get_executor_version_conda_env
get_executor_version = executor.get_executor_version
get_model_version_conda_env = model.get_model_version_conda_env
get_dataset_loader_version = dataset_loader.get_dataset_loader_version
delete_dataset_loader_version_tag = dataset_loader.delete_dataset_loader_version_tag
delete_executor_version_tag = executor.delete_executor_version_tag
delete_model_version_tag = model.delete_model_version_tag
set_dataset_loader_version_tag = dataset_loader.set_dataset_loader_version_tag
set_executor_version_tag = executor.set_executor_version_tag
set_model_version_tag = model.set_model_version_tag
set_dataset_loader_version_description = dataset_loader.set_dataset_loader_version_description
set_executor_version_description = executor.set_executor_version_description
set_model_version_description = model.set_model_version_description
set_model_description = model.set_model_description
set_executor_description = executor.set_executor_description
set_dataset_loader_description = dataset_loader.set_dataset_loader_description
delete_model_tag = model.delete_model_tag
delete_executor_tag = executor.delete_executor_tag
delete_dataset_loader_tag = dataset_loader.delete_dataset_loader_tag
set_dataset_loader_tag = dataset_loader.set_dataset_loader_tag
set_executor_tag = executor.set_executor_tag
set_model_tag = model.set_model_tag
get_latest_model_version = model.get_latest_model_version
get_latest_executor_version = executor.get_latest_executor_version
get_latest_dataset_loader_version = dataset_loader.get_latest_dataset_loader_version
get_initial_model_version = model.get_initial_model_version
get_initial_executor_version = executor.get_initial_executor_version
get_initial_dataset_loader_version = dataset_loader.get_initial_dataset_loader_version

set_dataset_loader_version_visibility = dataset_loader.set_dataset_loader_version_visibility
set_executor_version_visibility = executor.set_executor_version_visibility
set_model_version_visibility = model.set_model_version_visibility
set_model_visibility = model.set_model_visibility
set_executor_visibility = executor.set_executor_visibility
set_dataset_loader_visibility = dataset_loader.set_dataset_loader_visibility
set_experiment_visibility = experiment.set_experiment_visibility
set_job_visibility = job.set_job_visibility
